@@ -12,9 +12,11 @@ class ModelContainerDynesty(ModelContainer):
         self.nested_sampling_parameters = {'shutdown_jitter': False,
                                            'nthreads': 16,
                                            'include_priors': False,
-                                           'pfrac': 1.0,
+                                           'dlogz':0.01,
+                                           'pfrac': 0.00,
                                            'sample': 'auto',
-                                           'bound': 'multi'}
+                                           'bound': 'multi',
+                                           'use_threading_pool':True }
 
         self.output_directory = None
 
